#ifndef LIBKYFILESEC_H
#define LIBKYFILESEC_H

#ifdef __cplusplus
extern "C" {
#endif
/**
 * @brief 设置文件只读属性
 * @param filepath[in] 文件路径
 * @return int 返回0表示成功，返回非零表示失败
 */
extern int kdk_set_file_readonly(const char* filepath);

/**
 * @brief 取消文件只读属性
 * @param filepath[in] 文件路径
 * @return int 返回0表示成功，返回非零表示失败
 */
extern int kdk_cancel_file_readonly(const char* filepath);


/**
 * @brief 添加文件保护
 * 
 * @param path 文件路径
 * @return int 
 *          0: 成功
 *         -1：程序未授权
 *         -2：参数传入异常
 *         -3：参数路径不存在
 *         -4：添加程序至文件保护失败
 */
int kdk_set_file_protected(const char *path);

/**
 * @brief 解除文件保护
 * 
 * @param path 文件路径
 * @return int
 *          0：成功
 *         -1：程序未授权
 *         -2：参数传入异常
 *         -3：参数路径不存在
 *         -4：解除程序文件保护失败
 */
int kdk_clear_file_protected(const char *path);

/**
 * @brief 将目录内所有文件添加至文件保护
 * 
 * @param dpath 目录路径
 * @return int 
 *     >=0：成功添加文件保护数量
 *      -1：程序未授权
 *      -2：参数传入异常
 *      -3：参数路径不存在
 *      -4：添加目录内所有程序至文件保护失败
 */
int kdk_set_dir_protected(const char *dpath);

/**
 * @brief 将目录内所有文件解除文件保护
 * 
 * @param dpath 目录路径
 * @return int
 *     >=0：成功解除文件保护数量
 *      -1：程序未授权
 *      -2：参数传入异常
 *      -3：参数路径不存在
 *      -4：移除目录内所有程序至文件保护失败
 */
int kdk_clear_dir_protected(const char *dpath);

/**
 * @brief 获取所有文件保护节点
 * 
 * @param count 节点数量
 * @return char** 节点数组 
 *         NULL：失败或记录不存在
 */
char **kdk_get_file_protected(int *count);

#ifdef __cplusplus
}
#endif

#endif//LIBKYFILESEC_H
